(function (React, ReactDOM, d3) {
  'use strict';

  var React__default = 'default' in React ? React['default'] : React;
  ReactDOM = ReactDOM && Object.prototype.hasOwnProperty.call(ReactDOM, 'default') ? ReactDOM['default'] : ReactDOM;

  const Dataset =
    'https://gist.githubusercontent.com/Ramch16/4ecb38b804b06341d193b5b764867ec1/raw/a0b4a50f621ddeedc6b1859c86eebfd6789f9915/Test_ICE6_RAM.csv';
  const width = 860;
  const height = 500;
  const margin = { top: 20, right: -300, bottom: 50, left: 200 };

  const App = () => {
    const [data, setData] = React.useState(null);

    React.useEffect(() => {
      const row = d => {
        d.Ranking = +d['Ranking'];
        return d;
      };
      d3.csv(Dataset, row).then(data => {
        setData(data.slice(0, 20));
      });
    }, []);

    if (!data) {
      return React__default.createElement( 'pre', null, "please wait..." );
    }

    const innerHeight = height - margin.top - margin.bottom - 150;
    const innerWidth = width - margin.left - margin.right;

    const yAxis = d3.scaleBand()
      .domain(data.map(d => d.Indian_States))
      .range([0, innerHeight]);

    const xAxis = d3.scaleLinear()
      .domain([5, d3.max(data, d => d.Ranking)])
      .range([10, innerWidth]);
    return (
      React__default.createElement( 'svg', { width: width, height: height },
        React__default.createElement( 'g', { transform: `translate(${margin.left},${margin.top})` },
          xAxis.ticks().map(tickValue => (
            React__default.createElement( 'g', { key: tickValue, transform: `translate(${xAxis(tickValue)},10)` },
              React__default.createElement( 'line', { y2: innerHeight}),
              React__default.createElement( 'text', {
                style: { textAnchor: 'end' }, dy: ".90em", y: innerHeight + 9 },
                tickValue
              )
            )
          )),
          yAxis.domain().map(tickValue => (
            React__default.createElement( 'text', {
              key: tickValue, style: { textAnchor: 'end' }, x: -20, dy: ".32em", y: yAxis(tickValue) + yAxis.bandwidth() / 4 },
              tickValue
            )
          )),    
          data.map(d => (
            React__default.createElement( 'rect', {
              key: d.Indian_States, x: 0, y: yAxis(d.Indian_States), width: xAxis(d.Ranking), height: yAxis.bandwidth() })
          ))
        )
      )
    );
  };
  const rootElement = document.getElementById('root');
  ReactDOM.render(React__default.createElement( App, null ), rootElement);

}(React, ReactDOM, d3));
